@@ -20,6 +20,9 @@ FAILEDOPERATION_ARREARSERROR = 'FailedOperation.ArrearsError'
 # 身份证CardSide类型错误
 FAILEDOPERATION_CARDSIDEERROR = 'FailedOperation.CardSideError'
 
+# 图片分类失败
+FAILEDOPERATION_CLASSIFYSTOREFAILED = 'FailedOperation.ClassifyStoreFailed'
+
 # 今日次数达到限制。
 FAILEDOPERATION_COUNTLIMITERROR = 'FailedOperation.CountLimitError'
 
@@ -38,15 +41,15 @@ FAILEDOPERATION_EMPTYIMAGEERROR = 'FailedOperation.EmptyImageError'
 # 引擎识别超时。
 FAILEDOPERATION_ENGINERECOGNIZETIMEOUT = 'FailedOperation.EngineRecognizeTimeout'
 
+# 文件解码失败
+FAILEDOPERATION_FILEDECODEFAILED = 'FailedOperation.FileDecodeFailed'
+
 # 第二代身份证信息不合法或缺失（身份证号、姓名字段校验非法等）
 FAILEDOPERATION_IDCARDINFOILLEGAL = 'FailedOperation.IdCardInfoIllegal'
 
 # 图片分辨率过小或身份证在原图中的占比过小
 FAILEDOPERATION_IDCARDTOOSMALL = 'FailedOperation.IdCardTooSmall'
 
-# 银行卡信息非法。
-FAILEDOPERATION_ILLEGALBANKCARDERROR = 'FailedOperation.IllegalBankCardError'
-
 # 图片模糊。
 FAILEDOPERATION_IMAGEBLUR = 'FailedOperation.ImageBlur'
 
@@ -74,15 +77,21 @@ FAILEDOPERATION_INVOICEMISMATCH = 'FailedOperation.InvoiceMismatch'
 # 输入的Language不支持。
 FAILEDOPERATION_LANGUAGENOTSUPPORT = 'FailedOperation.LanguageNotSupport'
 
+# 入参CardSide错误，与实际上传的卡证正副页类型不符
+FAILEDOPERATION_LICENSECARDSIDEERROR = 'FailedOperation.LicenseCardSideError'
+
+# 图片中存在两张及以上同面卡证，请上传卡证单面图片或一正一反双面图片
+FAILEDOPERATION_LICENSEMULTICARDERROR = 'FailedOperation.LicenseMultiCardError'
+
 # 图片中存在两张及以上同面卡证，请上传卡证单面图片或一正一反双面图片。
 FAILEDOPERATION_MULTICARDERROR = 'FailedOperation.MultiCardError'
 
-# 非银行卡。
-FAILEDOPERATION_NOBANKCARDERROR = 'FailedOperation.NoBankCardError'
-
 # 非营业执照。
 FAILEDOPERATION_NOBIZLICENSE = 'FailedOperation.NoBizLicense'
 
+# 上传的图片非驾驶证
+FAILEDOPERATION_NODRIVERLICENSEERROR = 'FailedOperation.NoDriverLicenseError'
+
 # 非香港身份证。
 FAILEDOPERATION_NOHKIDCARD = 'FailedOperation.NoHKIDCard'
 
@@ -92,18 +101,33 @@ FAILEDOPERATION_NOMASIDCARD = 'FailedOperation.NoMASIDCard'
 # 非护照。
 FAILEDOPERATION_NOPASSPORT = 'FailedOperation.NoPassport'
 
+# 图片不属于门头照
+FAILEDOPERATION_NOSTORELABEL = 'FailedOperation.NoStoreLabel'
+
+# 上传的图片非行驶证
+FAILEDOPERATION_NOVEHICLELICENSEERROR = 'FailedOperation.NoVehicleLicenseError'
+
 # OCR识别失败。
 FAILEDOPERATION_OCRFAILED = 'FailedOperation.OcrFailed'
 
+# PDF解析失败。
+FAILEDOPERATION_PDFPARSEFAILED = 'FailedOperation.PDFParseFailed'
+
 # 未知错误。
 FAILEDOPERATION_UNKNOWERROR = 'FailedOperation.UnKnowError'
 
+# 未知的文件类型。
+FAILEDOPERATION_UNKNOWFILETYPEERROR = 'FailedOperation.UnKnowFileTypeError'
+
 # 服务未开通。
 FAILEDOPERATION_UNOPENERROR = 'FailedOperation.UnOpenError'
 
 # 剩余识别次数不足，请检查资源包状态。
 FAILEDOPERATION_USERQUOTAERROR = 'FailedOperation.UserQuotaError'
 
+# 通用告警服务异常
+FAILEDOPERATION_WARNINGSERVICEFAILED = 'FailedOperation.WarningServiceFailed'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -146,7 +170,7 @@ RESOURCENOTFOUND_NOINVOICE = 'ResourceNotFound.NoInvoice'
 # 不支持当天发票查询。
 RESOURCENOTFOUND_NOTSUPPORTCURRENTINVOICEQUERY = 'ResourceNotFound.NotSupportCurrentInvoiceQuery'
 
-# 帐号已欠费。
+# 账号已欠费。
 RESOURCEUNAVAILABLE_INARREARS = 'ResourceUnavailable.InArrears'
 
 # 账号资源包耗尽。
